import 'package:jinja/jinja.dart';
import 'package:test/test.dart';

void main() {
  group('Filter', () {
    Environment env = Environment();

    test('Filter Calling', () {
      expect(
          env.callFilter('sum', <dynamic>[
            [1, 2, 3]
          ]),
          equals(6));
    });

    test('Default', () {
      Template template = env
          .fromSource('{{ missing|default("no") }}|{{ false|default("no") }}|'
              '{{ false|default("no", true) }}|{{ given|default("no") }}');

      expect(template.render(<String, dynamic>{'given': 'yes'}),
          equals('no|false|no|yes'));
    });

    test('Batch', () {
      Template template = env.fromSource('{{ foo|batch(3)|list }}|'
          '{{ foo|batch(3, "X")|list }}');

      expect(
          template.render(<String, dynamic>{
            'foo': List<dynamic>.generate(10, (int i) => i)
          }),
          equals('[[0, 1, 2], [3, 4, 5], [6, 7, 8], [9]]|'
              '[[0, 1, 2], [3, 4, 5], [6, 7, 8], [9, X, X]]'));
    });

    test('Escape', () {
      Template template = env.fromSource('{{ \'<">&\'|escape }}');

      expect(template.render(), equals('&lt;&#34;&gt;&amp;'));
    });

    test('Lower', () {
      Template template = env.fromSource('{{ "FOO"|lower }}');

      expect(template.render(), equals('foo'));
    });

    test('Abs', () {
      Template template = env.fromSource('{{ -1|abs }}|{{ 1|abs }}');

      expect(template.render(), equals('1|1'));
    });
  });
}
